.. image:: _static/logo.png
        :alt: AS3 Ninja

.. image:: https://img.shields.io/travis/com/simonkowallik/as3ninja/master?style=flat-square
        :target: https://travis-ci.com/simonkowallik/as3ninja
        :alt: Travis CI Build Status
.. image:: https://img.shields.io/readthedocs/as3ninja/latest?style=flat-square
        :target: https://as3ninja.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
.. image:: https://img.shields.io/codeclimate/maintainability/simonkowallik/as3ninja?style=flat-square
        :target: https://codeclimate.com/github/simonkowallik/as3ninja
        :alt: Code Climate maintainability
.. image:: https://img.shields.io/codecov/c/github/simonkowallik/as3ninja?style=flat-square
        :target: https://codecov.io/gh/simonkowallik/as3ninja
        :alt: Test Coverage
